=========
Changelog 
=========

Easymunk 0.9.0 (2021-03-01)
---------------------------

**Forked from easymunk 6.0.0**

This is the first release of Easymunk.

Highlights - Major changes relative to Pymunk:

- Default to using angles rather than radians.
- Avoid using space.add/remove methods by adding factory functions in space.
- Create the Junction object to control multiple constraints between two objects.
